# API Docs

## Streamingml

### updateAMRulesRegressor *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#stream-processors">Stream Processor</a>)*

<p style="word-wrap: break-word">Performs build/update of AMRules Regressor model for evolving data streams.</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
streamingml:updateAMRulesRegressor(<STRING> model.name, <DOUBLE> split.confidence, <DOUBLE> tie.break.threshold, <INT> grace.period, <INT> change.detector, <INT> anomaly.detector, <DOUBLE|FLOAT|LONG|INT> model.features)
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">model.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the model to be build/updated.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">split.confidence</td>
        <td style="vertical-align: top; word-wrap: break-word">Hoeffding Bound Parameter. The allowable error in split decision, values closer to 0 will take longer to decide.</td>
        <td style="vertical-align: top">1.0E-7D</td>
        <td style="vertical-align: top">DOUBLE</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tie.break.threshold</td>
        <td style="vertical-align: top; word-wrap: break-word">Hoeffding Bound Parameter. Threshold below which a split will be forced to break ties.</td>
        <td style="vertical-align: top">0.05D</td>
        <td style="vertical-align: top">DOUBLE</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">grace.period</td>
        <td style="vertical-align: top; word-wrap: break-word">Hoeffding Bound Parameter. The number of instances a leaf should observe between split attempts.</td>
        <td style="vertical-align: top">200</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">change.detector</td>
        <td style="vertical-align: top; word-wrap: break-word">Concept Drift detection methodology. 0:NoChangeDetection, 1:ADWINChangeDetector, 2:PageHinkleyDM</td>
        <td style="vertical-align: top">2:PageHinkleyDM</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">anomaly.detector</td>
        <td style="vertical-align: top; word-wrap: break-word">Anomaly Detection Methodology. 0:NoAnomalyDetection, 1:AnomalinessRatioScore, 2:OddsRatioScore</td>
        <td style="vertical-align: top">2:OddsRatioScore</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">model.features</td>
        <td style="vertical-align: top; word-wrap: break-word">Features of the model which should be attributes of the stream.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">DOUBLE<br>FLOAT<br>LONG<br>INT</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>
<span id="extra-return-attributes" class="md-typeset" style="display: block; font-weight: bold;">Extra Return Attributes</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Possible Types</th>
    </tr>
    <tr>
        <td style="vertical-align: top">meanSquaredError</td>
        <td style="vertical-align: top; word-wrap: break-word">The current Mean Squared Error of the model</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, attribute_4 string );

from StreamA#streamingml:updateAMRulesRegressor('model1',) 
select attribute_0, attribute_1, attribute_2, attribute_3, meanSquaredError insert into outputStream;
```
<p style="word-wrap: break-word">An AMRulesRegressor model with the name 'model1' will be built/updated under using attribute_0, attribute_1, attribute_2, attribute_3 as features and attribute_4 as the target_value. The accuracy evaluation will be emitted to the outputStream</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, attribute_4 string );

from StreamA#streamingml:updateAMRulesRegressor('model1', 1.0E-7D, 0.05D, 200, 0, 0) 
select attribute_0, attribute_1, attribute_2, attribute_3, meanSquaredError insert into outputStream;
```
<p style="word-wrap: break-word">An AMRulesRegressor model with the name 'model1' will be built/updated with a split confidence of 1.0E-7D, tie break threshold of 0.05D, a grace period of 200, NoChangeDetection and NoAnomalyDetection using attribute_0, attribute_1, attribute_2, attribute_3 as features and attribute_4 as the target value. The meanSquaredError will be emitted to the outputStream.</p>

### AMRulesRegressor *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#stream-processors">Stream Processor</a>)*

<p style="word-wrap: break-word">Performs Regression task with AMRulesRegressor </p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
streamingml:AMRulesRegressor(<STRING> model.name, <INT|FLOAT|FLOAT|DOUBLE> feature.vector)
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">model.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the model to be used for prediction.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">feature.vector</td>
        <td style="vertical-align: top; word-wrap: break-word">The feature vector for the regression analysis</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">INT<br>FLOAT<br>FLOAT<br>DOUBLE</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>
<span id="extra-return-attributes" class="md-typeset" style="display: block; font-weight: bold;">Extra Return Attributes</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Possible Types</th>
    </tr>
    <tr>
        <td style="vertical-align: top">featureVector</td>
        <td style="vertical-align: top; word-wrap: break-word">The feature vector used for the regression analysis</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
    <tr>
        <td style="vertical-align: top">prediction</td>
        <td style="vertical-align: top; word-wrap: break-word">Predicted value</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
    <tr>
        <td style="vertical-align: top">meanSquaredError</td>
        <td style="vertical-align: top; word-wrap: break-word">MeanSquaredError of the predicting model</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double);

from StreamA#streamingml:AMRulesRegressor('model1',  attribute_0, attribute_1, attribute_2, attribute_3) 
select attribute_0, attribute_1, attribute_2, attribute_3, prediction, meanSquaredError insert into outputStream;
```
<p style="word-wrap: break-word">An AMRules model with the name 'model1' will be used to predict the value for the feature vector represented by attribute_0, attribute_1, attribute_2, attribute_3. Predicted value along with the MeanSquaredError and the feature vector will be emitted to the outputStream. The outputStream will have following definition; (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, prediction double, meanSquaredError double).</p>

### hoeffdingTreeClassifier *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#stream-processors">Stream Processor</a>)*

<p style="word-wrap: break-word">Performs classification with Hoeffding Adaptive Tree for evolving data streams that uses ADWIN to replace branches for new ones.</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
streamingml:hoeffdingTreeClassifier(<STRING> model.name)
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">model.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the model to be used for prediction.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>
<span id="extra-return-attributes" class="md-typeset" style="display: block; font-weight: bold;">Extra Return Attributes</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Possible Types</th>
    </tr>
    <tr>
        <td style="vertical-align: top">prediction</td>
        <td style="vertical-align: top; word-wrap: break-word">Predicted class label</td>
        <td style="vertical-align: top">STRING</td>
    </tr>
    <tr>
        <td style="vertical-align: top">confidenceLevel</td>
        <td style="vertical-align: top; word-wrap: break-word">Probability of the prediction</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double);

from StreamA#streamingml:hoeffdingTreeClassifier('model1',  attribute_0, attribute_1, attribute_2, attribute_3) 
select attribute_0, attribute_1, attribute_2, attribute_3, prediction, predictionConfidence insert into outputStream;
```
<p style="word-wrap: break-word">A Hoeffding Tree model with the name 'model1' will be used to predict the label of the feature vector represented by attribute_0, attribute_1, attribute_2, attribute_3. Predicted label (String/Bool) along with the Prediction Confidence and the feature vector will be emitted to the outputStream. The outputStream will have following definition; (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, prediction string, confidenceLevel double).</p>

### updateHoeffdingTree *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#stream-processors">Stream Processor</a>)*

<p style="word-wrap: break-word">Performs build/update of Hoeffding Adaptive Tree for evolving data streams that uses ADWIN to replace branches for new ones.</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
streamingml:updateHoeffdingTree(<STRING> model.name, <INT> no.of.classes, <INT> grace.period, <INT> split.criterion, <DOUBLE> split.confidence, <DOUBLE> tie.break.threshold, <BOOL> binary.split, <BOOL> pre.prune, <INT> leaf.prediction.strategy, <DOUBLE|INT> model.features)
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">model.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the model to be build/updated.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">no.of.classes</td>
        <td style="vertical-align: top; word-wrap: break-word">The number of Class labels in the datastream.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">grace.period</td>
        <td style="vertical-align: top; word-wrap: break-word">The number of instances a leaf should observe between split attempts. min:0, max:2147483647</td>
        <td style="vertical-align: top">200</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">split.criterion</td>
        <td style="vertical-align: top; word-wrap: break-word">Split criterion to use. 0:InfoGainSplitCriterion, 1:GiniSplitCriterion</td>
        <td style="vertical-align: top">0:InfoGainSplitCriterion</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">split.confidence</td>
        <td style="vertical-align: top; word-wrap: break-word">The allowable error in split decision, values closer to 0 will take longer to decide.</td>
        <td style="vertical-align: top">1e-7</td>
        <td style="vertical-align: top">DOUBLE</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tie.break.threshold</td>
        <td style="vertical-align: top; word-wrap: break-word">Threshold below which a split will be forced to break ties. min:0.0D, max:1.0D</td>
        <td style="vertical-align: top">0.05D</td>
        <td style="vertical-align: top">DOUBLE</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">binary.split</td>
        <td style="vertical-align: top; word-wrap: break-word">Only allow binary splits.</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">pre.prune</td>
        <td style="vertical-align: top; word-wrap: break-word">Disable pre-pruning</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">leaf.prediction.strategy</td>
        <td style="vertical-align: top; word-wrap: break-word">Leaf prediction to use. 0:Majority class, 1:Naive Bayes, 2:Naive Bayes Adaptive.</td>
        <td style="vertical-align: top">2:Naive Bayes Adaptive</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">model.features</td>
        <td style="vertical-align: top; word-wrap: break-word">Features of the model which should be attributes of the stream.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">DOUBLE<br>INT</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>
<span id="extra-return-attributes" class="md-typeset" style="display: block; font-weight: bold;">Extra Return Attributes</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Possible Types</th>
    </tr>
    <tr>
        <td style="vertical-align: top">accuracy</td>
        <td style="vertical-align: top; word-wrap: break-word">The accuracy evaluation of the model(Prequnetial Evaluation)</td>
        <td style="vertical-align: top">DOUBLE</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, attribute_4 string );

from StreamA#streamingml:updateHoeffdingTree('model1', 3) 
select attribute_0, attribute_1, attribute_2, attribute_3, accuracy insert into outputStream;
```
<p style="word-wrap: break-word">A HoeffdingTree model with the name 'model1' will be built/updated under 3 number of classes using attribute_0, attribute_1, attribute_2, attribute_3 as features and attribute_4 as the label. The accuracy evaluation will be emitted to the outputStream</p>

<span id="example-2" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 2</span>
```
define stream StreamA (attribute_0 double, attribute_1 double, attribute_2 double, attribute_3 double, attribute_4 string );

from StreamA#streamingml:updateHoeffdingTree('model1', 3, 200, 0, 1e-7, 1.0D, true, true, 2) 
select attribute_0, attribute_1, attribute_2, attribute_3, accuracy insert into outputStream;
```
<p style="word-wrap: break-word">A Hoeffding Tree model with the name 'model1' will be built/updated with a grace period of 200, InformationGain Split criterion,1e-7 of allowable error in split decision, 1.0D of breaktie threshold, allowing only binary splits, disabled pre-pruning, Naive Bayes Adaptive asleaf prediction using attribute_0, attribute_1, attribute_2, attribute_3 as features and attribute_4 as the label. The accuracy evaluation will be emitted to the outputStream.</p>

